#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 genvalidity-hspec
version:              1.0.0.4
visibility:           public
id:                   genvalidity-hspec-1.0.0.4-48EkoCT21vn2jG8xfM7A4
key:                  genvalidity-hspec-1.0.0.4-48EkoCT21vn2jG8xfM7A4
license:              MIT
copyright:            Copyright: (c) 2016-2021 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Standard spec'\''s for GenValidity instances
description:
    Note: There are companion packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-hspec-aeson genvalidity-hspec-aeson>

    * <https://hackage.haskell.org/package/genvalidity-hspec-binary genvalidity-hspec-binary>

    * <https://hackage.haskell.org/package/genvalidity-hspec-cereal genvalidity-hspec-cereal>

    * <https://hackage.haskell.org/package/genvalidity-hspec-hashable genvalidity-hspec-hashable>

category:             Testing
abi:                  d07adf066b929c2a85c7b727b0d22b1d
exposed:              True
exposed-modules:
    Test.Validity Test.Validity.Applicative Test.Validity.Arbitrary
    Test.Validity.Eq Test.Validity.Functor Test.Validity.GenValidity
    Test.Validity.Monad Test.Validity.Monoid Test.Validity.Ord
    Test.Validity.Show Test.Validity.Shrinking Test.Validity.Utils

hidden-modules:       Paths_genvalidity_hspec
import-dirs:          /usr/lib/ghc-9.6.6/site-local/genvalidity-hspec-1.0.0.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/genvalidity-hspec-1.0.0.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/genvalidity-hspec-1.0.0.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-genvalidity-hspec
hs-libraries:         HSgenvalidity-hspec-1.0.0.4-48EkoCT21vn2jG8xfM7A4
depends:
    QuickCheck-2.15.0.1-K0JFHgomBHu3hU8T85EWwT base-4.18.2.1
    genvalidity-1.1.1.0-6GyHRId3mAEISf8VW3ors5
    genvalidity-property-1.0.0.0-DzP4r1EZH4NKliSfFwI2
    hspec-2.11.7-3Kp3PTiLFy0JhU2sO60TrZ
    hspec-core-2.11.7-7fX3F8gLgA3T5SWesER1k transformers-0.6.1.0
    validity-0.12.1.0-9RPdtJR53ls5XrYCO8sXV7

haddock-interfaces:
    /usr/share/doc/haskell-genvalidity-hspec/html/genvalidity-hspec.haddock

haddock-html:         /usr/share/doc/haskell-genvalidity-hspec/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

